pub struct Event<T> { /* private fields */ }Expand description
A struct which represents some event.
Generic parameter T is a type of argument which callbacks accept.
Implementations
Sourceimpl<T> Event<T>
impl<T> Event<T>
Sourcepub fn connect<F>(&self, callback: F) -> usize
pub fn connect<F>(&self, callback: F) -> usize
Registers the provided callback to invoke when the event is emitted.
Returns an ID which can be used to unregister the callback using
disconnect.
Sourcepub fn disconnect(&self, handle: usize)
pub fn disconnect(&self, handle: usize)
Unregister the callback by its ID.